@@ -14,21 +14,25 @@ to export objects or claim well-known names.
 # Copyright (C) 2004 Rob Taylor
 # Copyright (C) 2005, 2006 Collabora Ltd. <http://www.collabora.co.uk/>
 #
-# Licensed under the Academic Free License version 2.1
+# Permission is hereby granted, free of charge, to any person
+# obtaining a copy of this software and associated documentation
+# files (the "Software"), to deal in the Software without
+# restriction, including without limitation the rights to use, copy,
+# modify, merge, publish, distribute, sublicense, and/or sell copies
+# of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
+# The above copyright notice and this permission notice shall be
+# included in all copies or substantial portions of the Software.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
+# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
+# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
+# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+# DEALINGS IN THE SOFTWARE.
 
 import os
 
@@ -50,13 +54,12 @@ __all__ = (
            'LOCAL_PATH', 'LOCAL_IFACE', 'PEER_IFACE',
            'INTROSPECTABLE_IFACE', 'PROPERTIES_IFACE',
 
-           'DBusException',
-
            'ObjectPath', 'ByteArray', 'Signature', 'Byte', 'Boolean',
            'Int16', 'UInt16', 'Int32', 'UInt32', 'Int64', 'UInt64',
            'Double', 'String', 'Array', 'Struct', 'Dictionary', 'UTF8String',
 
            # from exceptions
+           'DBusException',
            'MissingErrorHandlerException', 'MissingReplyHandlerException',
            'ValidationException', 'IntrospectionParserException',
            'UnknownMethodException', 'NameExistsException',
@@ -82,14 +85,14 @@ from _dbus_bindings import get_default_main_loop, set_default_main_loop,\
 from _dbus_bindings import BUS_DAEMON_NAME, BUS_DAEMON_PATH, BUS_DAEMON_IFACE,\
                            LOCAL_PATH, LOCAL_IFACE, PEER_IFACE,\
                            INTROSPECTABLE_IFACE, PROPERTIES_IFACE
-from _dbus_bindings import DBusException
 
 from dbus.exceptions import MissingErrorHandlerException, \
                             MissingReplyHandlerException, \
                             ValidationException, \
                             IntrospectionParserException, \
                             UnknownMethodException, \
-                            NameExistsException
+                            NameExistsException, \
+                            DBusException
 from _dbus_bindings import ObjectPath, ByteArray, Signature, Byte, Boolean,\
                            Int16, UInt16, Int32, UInt32, Int64, UInt64,\
                            Double, String, Array, Struct, Dictionary, \
